@@ -9,7 +9,10 @@ describe 'mistral::db::mysql' do
   end
 
   let :facts do
-    OSDefaults.get_facts({ :osfamily => 'Debian' })
+    OSDefaults.get_facts({
+      :osfamily => 'Debian',
+      :os       => { :name  => 'Debian', :family => 'Debian', :release => { :major => '8', :minor => '0' } },
+    })
   end
 
   let :params do
