@@ -3,7 +3,6 @@ describe 'mistral' do
   let :req_params do
     {
       :database_connection => 'mysql://user:password@host/database',
-      :keystone_password   => 'foo',
       :purge_config        => false,
     }
   end
@@ -13,9 +12,16 @@ describe 'mistral' do
       :osfamily               => 'Debian',
       :operatingsystem        => 'Debian',
       :operatingsystemrelease => 'jessie',
+      :os       => { :name  => 'Debian', :family => 'Debian', :release => { :major => '8', :minor => '0' } },
     })
   end
 
+  let :pre_condition do
+      "class { '::mistral::keystone::authtoken':
+         password => 'foo',
+       }"
+  end
+
   describe 'with only required params' do
     let :params do
       req_params
@@ -69,7 +75,7 @@ describe 'mistral' do
 
   end
 
-  describe 'a single rabbit_host with enable ha queues' do
+  describe 'with enable ha queues' do
     let :params do
       req_params.merge({'rabbit_ha_queues' => true})
     end
